From 968a46b11ce8e6b2321bef2421681618d88a5dba Mon Sep 17 00:00:00 2001
From: Daniel Campbell <dlcampbell@gmx.com>
Date: Sat, 20 Oct 2018 02:04:56 -0700
Subject: [PATCH 2/2] ui: add classes to supplement missing summary info

The prior 'summary' attributes could be used in CSS 3 to style elements.
This commit adds classes to make up for the loss of these attributes, so
style writers can adapt their styles without losing specificity.

Signed-off-by: Daniel Campbell <dlcampbell@gmx.com>
---
 ui-diff.c     | 2 +-
 ui-repolist.c | 2 +-
 ui-summary.c  | 2 +-
 ui-tree.c     | 2 +-
 4 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/ui-diff.c b/ui-diff.c
index 5c9011f..1d7054f 100644
--- a/ui-diff.c
+++ b/ui-diff.c
@@ -113,7 +113,7 @@ static void print_fileinfo(struct fileinfo *info)
 	}
 	htmlf("%d", info->added + info->removed);
 	html("</td><td class='graph'>");
-	htmlf("<table width='%d%%'><tr>", (max_changes > 100 ? 100 : max_changes));
+	htmlf("<table class='diffstat' width='%d%%'><tr>", (max_changes > 100 ? 100 : max_changes));
 	htmlf("<td class='add' style='width: %.1f%%;'/>",
 	      info->added * 100.0 / max_changes);
 	htmlf("<td class='rem' style='width: %.1f%%;'/>",
diff --git a/ui-repolist.c b/ui-repolist.c
index 2f884e7..52f29db 100644
--- a/ui-repolist.c
+++ b/ui-repolist.c
@@ -293,7 +293,7 @@ void cgit_print_repolist(void)
 	else if (ctx.cfg.section_sort)
 		sort_repolist("section");
 
-	html("<table class='list nowrap'>");
+	html("<table class='repo-list list nowrap'>");
 	for (i = 0; i < cgit_repolist.count; i++) {
 		ctx.repo = &cgit_repolist.repos[i];
 		if (!is_visible(ctx.repo))
diff --git a/ui-summary.c b/ui-summary.c
index 73b3732..d451b5e 100644
--- a/ui-summary.c
+++ b/ui-summary.c
@@ -50,7 +50,7 @@ void cgit_print_summary(void)
 		columns++;
 
 	cgit_print_layout_start();
-	html("<table class='list nowrap'>");
+	html("<table class='repo-info list nowrap'>");
 	cgit_print_branches(ctx.cfg.summary_branches);
 	htmlf("<tr class='nohover'><td colspan='%d'>&nbsp;</td></tr>", columns);
 	cgit_print_tags(ctx.cfg.summary_tags);
diff --git a/ui-tree.c b/ui-tree.c
index be25918..9134838 100644
--- a/ui-tree.c
+++ b/ui-tree.c
@@ -264,7 +264,7 @@ static int ls_item(const struct object_id *oid, struct strbuf *base,
 static void ls_head(void)
 {
 	cgit_print_layout_start();
-	html("<table class='list'>\n");
+	html("<table class='tree-list list'>\n");
 	html("<tr class='nohover'>");
 	html("<th class='left'>Mode</th>");
 	html("<th class='left'>Name</th>");
-- 
2.19.1

